"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * 判断是否是对象
 *
 * @export
 * @param {*} obj
 * @returns {boolean}
 */
function isObject(obj) {
    return obj !== null && typeof obj === 'object';
}
exports.isObject = isObject;
/**
 * 判断是否是string
 *
 * @export
 * @param {*} str
 * @returns
 */
function isString(str) {
    return typeof str === 'string';
}
exports.isString = isString;
/**
 * 判断对象是否是空
 *
 * @export
 * @param {*} obj
 * @returns
 */
function isEmptyObject(obj) {
    return Object.keys(obj).length === 0;
}
exports.isEmptyObject = isEmptyObject;
/**
 * 判断是否是function
 *
 * @export
 * @param {*} fn
 * @returns
 */
function isFn(fn) {
    return typeof fn === "function";
}
exports.isFn = isFn;
/**
 * 对样式进行处理，判断样式是否需要传递到子组件
 * 如果需要传递到子组件，则打包好样式返回对应的对象
 *
 * @param {*} styles
 * @returns {*}
 */
function handleStyles(styles) {
    var objStyles = [];
    if (!isObject(styles) && !isEmptyObject(styles)) {
        return objStyles;
    }
    for (var p in styles) {
        if (p.match(/c____+\d+____/)) {
            var pMatch = p.match(/c____+\d+____/);
            var s = pMatch[0];
            var c = s.match(/\d/)[0];
            var cInt = parseInt(c);
            var childStyleName = void 0;
            var lastChildStyleName = void 0;
            if (cInt > 0) {
                var lastName = p.substr(10, p.length - 10);
                childStyleName = 'c____' + (cInt - 1) + '____' + lastName;
                lastChildStyleName = lastName;
                objStyles.push({
                    c: c,
                    p: p,
                    styleName: styles[p],
                    childStyleName: childStyleName,
                    lastChildStyleName: lastChildStyleName
                });
            }
        }
    }
    return objStyles;
}
/**
 * 样式向子组件传递
 *
 * @export
 * @param {*} _this
 * @returns
 */
function stylesToChildComponet(_this) {
    var parent = _this.$parent;
    var styles = _this.$options.style;
    if (!parent) {
        return;
    }
    if (isObject(parent.$options.style)) {
        var parentStyle = parent.$options.style;
        if (!parentStyle) {
            return;
        }
        var pStyleObject = handleStyles(parentStyle);
        if (styles === void 0) {
            styles = _this.$options.style = {};
        }
        pStyleObject.forEach(function (element) {
            if (parseInt(element.c) > 0) {
                styles[element.childStyleName] = element.styleName;
                styles[element.lastChildStyleName] = element.styleName;
            }
        });
    }
}
exports.stylesToChildComponet = stylesToChildComponet;
//# sourceMappingURL=helper.js.map